from cms.plugin_pool import plugin_pool
from cms.plugin_base import CMSPluginBase
from djangocms_grid.models import Grid, GridColumn, DJANGOCMS_GRID_SIZE
from django.utils.translation import ugettext_lazy as _
from djangocms_grid.forms import GridPluginForm
from cms.models import CMSPlugin


class GridPlugin(CMSPluginBase):
    model = Grid
    name = _('Multi Columns (grid)')
    module = _('Multi Columns')
    render_template = 'djangocms_grid/grid.html'
    allow_children = True
    child_classes = ['GridColumnPlugin']
    form = GridPluginForm

    def render(self, context, instance, placeholder):
        context.update({
            'grid': instance,
            'placeholder': placeholder,
            'GRID_SIZE': DJANGOCMS_GRID_SIZE,
        })
        return context

    def save_model(self, request, obj, form, change):
        response = super(GridPlugin, self).save_model(request, obj, form, change)
        for x in xrange(int(form.cleaned_data['create'])):
            col = GridColumn(parent=obj, placeholder=obj.placeholder, language=obj.language, size=form.cleaned_data['create_size'], position=CMSPlugin.objects.filter(parent=obj).count(), plugin_type=GridColumnPlugin.__name__)
            col.save()
        return response


class GridColumnPlugin(CMSPluginBase):
    model = GridColumn
    name = _('Grid Column')
    module = _('Multi Columns')
    render_template = 'djangocms_grid/column.html'
    allow_children = True

    def render(self, context, instance, placeholder):
        context.update({
            'column': instance,
            'placeholder': placeholder,
        })
        return context

plugin_pool.register_plugin(GridPlugin)
plugin_pool.register_plugin(GridColumnPlugin)



from cms.models import CMSPlugin
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings

DJANGOCMS_GRID_SIZE = getattr(settings, 'DJANGOCMS_COLUMN_960_COLUMNS', 24)
DJANGOCMS_GRID_CHOICES = [
    ('%s' % i, 'grid-%s' % i) for i in range(1, DJANGOCMS_GRID_SIZE)
]


class Grid(CMSPlugin):
    inner = models.BooleanField(_('inner'), default=True, help_text=_('Defines whether the plugin is already inside a grid container or another Multi-column plugin.'))
    custom_classes = models.CharField(_('custom classes'), max_length=200, blank=True)

    def __unicode__(self):
        return _(u"%s columns") % self.cmsplugin_set.all().count()


class GridColumn(CMSPlugin):
    size = models.CharField(_('size'), choices=DJANGOCMS_GRID_CHOICES, default='1', max_length=50)
    custom_classes = models.CharField(_('custom classes'), max_length=200, blank=True)

    def __unicode__(self):
        return u"%s" % self.get_size_display()




from django import forms
from djangocms_grid.models import Grid, DJANGOCMS_GRID_CHOICES, DJANGOCMS_GRID_SIZE
from django.utils.translation import ugettext_lazy as _

NUM_COLUMNS = [
    (i, '%s' % i) for i in range(0, DJANGOCMS_GRID_SIZE)
]


class GridPluginForm(forms.ModelForm):
    create = forms.ChoiceField(choices=NUM_COLUMNS, label=_('Create Columns'), help_text=_('Create this number of columns inside'))
    create_size = forms.ChoiceField(choices=DJANGOCMS_GRID_CHOICES, label=_('Column size'), help_text=('Width of created columns. You can still change the width of the column afterwards.'))

    class Meta:
        model = Grid
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')
